@@ -32,7 +32,7 @@
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.12'
+__version__ = '0.14'
 
 
 import os
@@ -85,17 +85,18 @@ class CliRecordLib:
                                               'core_return']
     search_target = options.target
     if( record_type == u'ptr' ):
-      search_target = roster_client_lib.RunFunction(
+      search_target, options.zone_name = roster_client_lib.RunFunction(
           'GetPTRTarget', options.username, credfile=options.credfile,
           server_name=options.server,
           args=[options.target, options.view_name],
-          raise_errors=raise_errors)['core_return'][0]
-    elif( record_type == u'aaaa' ):
-      expanded_ip = roster_client_lib.RunFunction(
-          u'ExpandIPV6', options.username, credfile=options.credfile,
-          args=[record_args_dict['assignment_ip']], server_name=options.server,
           raise_errors=raise_errors)['core_return']
-      record_args_dict['assignment_ip'] = expanded_ip
+    elif( record_type == u'aaaa' ):
+      if( record_args_dict['assignment_ip'] is not None ):
+        expanded_ip = roster_client_lib.RunFunction(
+            u'ExpandIPV6', options.username, credfile=options.credfile,
+            args=[record_args_dict['assignment_ip']], server_name=options.server,
+            raise_errors=raise_errors)['core_return']
+        record_args_dict['assignment_ip'] = expanded_ip
     ## Check if view exists
     if( not views.has_key(options.view_name) and options.view_name != 'any' ):
       self.cli_common_lib_instance.DnsError('View does not exist!', 2)
@@ -118,14 +119,18 @@ class CliRecordLib:
             break
         else:
           self.cli_common_lib_instance.DnsError('Duplicate record!', 4)
-      function = u'MakeRecord'
       if( fix_ptr_origin and record_type == u'ptr' ):
-        function = u'MakePTRRecord'
-      roster_client_lib.RunFunction(
-          function, options.username, credfile=options.credfile,
-          args=[record_type, options.target, options.zone_name, record_args_dict],
-          kwargs={'view_name': options.view_name, 'ttl': int(options.ttl)},
-          server_name=options.server, raise_errors=raise_errors)
+        roster_client_lib.RunFunction(
+            'MakePTRRecord', options.username, credfile=options.credfile,
+            args=[options.target, record_args_dict],
+            kwargs={'view_name': options.view_name, 'ttl': int(options.ttl)},
+            server_name=options.server, raise_errors=raise_errors)
+      else:
+        roster_client_lib.RunFunction(
+            'MakeRecord', options.username, credfile=options.credfile,
+            args=[record_type, options.target, options.zone_name, record_args_dict],
+            kwargs={'view_name': options.view_name, 'ttl': int(options.ttl)},
+            server_name=options.server, raise_errors=raise_errors)
       if( options.view_name is None ):
         options.view_name = u'any'
       if( options.ttl is None ):
@@ -138,9 +143,9 @@ class CliRecordLib:
             arg_list.append('DEFAULT')
           else:
             arg_list.append(str(record_args_dict[argument]))
-        print 'ADDED AAAA: %s zone_name: %s view_name: %s ttl: %s' % (
-            options.target, options.zone_name, options.view_name,
-            options.ttl)
+        print 'ADDED %s: %s zone_name: %s view_name: %s ttl: %s' % (
+            record_type.upper(), options.target, options.zone_name,
+            options.view_name, options.ttl)
         print '    %s' % ' '.join(arg_list)
     elif( record_type == u'ptr' ):
       roster_client_lib.RunFunction(
@@ -204,17 +209,18 @@ class CliRecordLib:
         self.cli_common_lib_instance.DnsError('Must specify --%s-%s' % (
             record_type, item.replace('_', '-')), 1)
     if( record_type == u'ptr' ):
-      options.target = roster_client_lib.RunFunction(
+      options.target, options.zone_name = roster_client_lib.RunFunction(
           'GetPTRTarget', options.username, credfile=options.credfile,
           server_name=options.server,
           args=[options.target, options.view_name],
-          raise_errors=raise_errors)['core_return'][0]
-    elif( record_type == u'aaaa' ):
-      expanded_ip = roster_client_lib.RunFunction(
-          u'ExpandIPV6', options.username, credfile=options.credfile,
-          args=[record_args_dict['assignment_ip']], server_name=options.server,
           raise_errors=raise_errors)['core_return']
-      record_args_dict['assignment_ip'] = expanded_ip
+    elif( record_type == u'aaaa' ):
+      if( record_args_dict['assignment_ip'] is not None ):
+        expanded_ip = roster_client_lib.RunFunction(
+            u'ExpandIPV6', options.username, credfile=options.credfile,
+            args=[record_args_dict['assignment_ip']], server_name=options.server,
+            raise_errors=raise_errors)['core_return']
+        record_args_dict['assignment_ip'] = expanded_ip
 
     options.credfile = os.path.expanduser(options.credfile)
     views = roster_client_lib.RunFunction(
@@ -270,16 +276,17 @@ class CliRecordLib:
     """
     search_target = options.target
     if( record_type == u'ptr' ):
-        search_target = roster_client_lib.RunFunction(
+        search_target, options.zone_name = roster_client_lib.RunFunction(
             'GetPTRTarget', options.username, credfile=options.credfile,
             server_name=options.server,
-            args=[options.target, options.view_name])['core_return'][0]
+            args=[options.target, options.view_name])['core_return']
     elif( record_type == u'aaaa' ):
-      expanded_ip = roster_client_lib.RunFunction(
-          u'ExpandIPV6', options.username, credfile=options.credfile,
-          args=[record_args_dict['assignment_ip']],
-          server_name=options.server)['core_return']
-      record_args_dict['assignment_ip'] = expanded_ip
+      if( record_args_dict['assignment_ip'] is not None ):
+        expanded_ip = roster_client_lib.RunFunction(
+            u'ExpandIPV6', options.username, credfile=options.credfile,
+            args=[record_args_dict['assignment_ip']],
+            server_name=options.server)['core_return']
+        record_args_dict['assignment_ip'] = expanded_ip
     records = roster_client_lib.RunFunction(
         'ListRecords', options.username, credfile=options.credfile,
         server_name=options.server,
