@@ -35,7 +35,7 @@ Connects to XML RPC server and runs arbitrary functions.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.12'
+__version__ = '0.14'
 
 
 import os
@@ -90,9 +90,14 @@ def RunFunction(function, user_name, credfile=None, credstring=None,
   except xmlrpclib.Fault, e:
     if( raise_errors ):
       raise
-    print "SERVER ERROR: %s" % e.faultString
-    sys.exit(1)
+    cli_common_lib.ServerError(str(e), 'UNKNOWN', 1) # This should never happen
 
+  if( type(core_return) == dict and core_return['error'] ):
+    if( raise_errors ):
+      raise xmlrpclib.Fault(1, '(%s) %s' % (core_return['log_uuid_string'],
+                                            core_return['error']))
+    cli_common_lib.ServerError(core_return['error'],
+                               core_return['log_uuid_string'], 1)
 
   if( core_return == 'ERROR: Invalid Credentials' ):
       if( not CheckCredentials(user_name, credfile, server_name,
@@ -128,6 +133,10 @@ def GetCredentials(user_name, password, credfile=None,
   """
   server = xmlrpclib.ServerProxy(server_name, allow_none=True)
   credential = server.GetCredentials(user_name, password)
+  if( type(credential) == dict ):
+    if( 'error' in credential ):
+      cli_common_lib.ServerError(credential['error'],
+                                 credential['log_uuid_string'], 1)
   if( credfile is not None ):
     credfile = os.path.expanduser(credfile)
     try:
@@ -167,7 +176,12 @@ def IsAuthenticated(user_name, credfile,
   else:
     return False
   server = xmlrpclib.ServerProxy(server_name, allow_none=True)
-  return server.IsAuthenticated(user_name, credstring)
+  authenticated = server.IsAuthenticated(user_name, credstring)
+  if( type(authenticated) == dict and 'error' in authenticated ):
+      cli_common_lib.ServerError(authenticated['error'],
+                                 authenticated['log_uuid_string'], 1)
+  else:
+    return authenticated
 
 def CheckCredentials(username, credfile, server, password=None):
   """Checks if credential file is valid.
